#[non_exhaustive]pub enum CatalogFileFormat {
Po,
Fcl,
}Available on crate feature
catalog only.Expand description
File format used by disk-based catalog combine operations.
This enum is non-exhaustive because Ferrocat can add additional catalog file formats over time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Po
Classic gettext PO catalog files, including gettext template (.pot) files.
Fcl
Ferrocat Catalog Lines (.fcl) files.
Implementations
Sourceimpl CatalogFileFormat
impl CatalogFileFormat
Sourcepub fn infer_from_path(path: &Path) -> Result<Self, ApiError>
pub fn infer_from_path(path: &Path) -> Result<Self, ApiError>
Infers a catalog file format from a path extension.
Supported path suffixes are .po, .pot, and .fcl.
Errors
Returns ApiError::Unsupported when the path suffix does not map to a
supported catalog file format.