#[non_exhaustive]pub enum CatalogMachineTranslationStatus {
Current,
Stale,
Absent,
Invalid,
}Available on crate feature
catalog only.Expand description
Machine-translation metadata freshness status.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Current
Metadata hash matches the current effective translation.
Stale
Metadata hash does not match the current effective translation.
Absent
No machine-translation metadata is present.
Invalid
Metadata is invalid in a way the parsed catalog representation can expose.