#[non_exhaustive]pub enum CatalogMessageStatus {
Translated,
Missing,
Empty,
Obsolete,
Extra,
}Available on crate feature
catalog only.Expand description
Canonical catalog message status used by coverage and review reports.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Translated
Active target message exists and has a non-empty translation.
Missing
No active or obsolete target entry exists for the active source identity.
Empty
Active target entry exists, but its effective translation is empty.
Obsolete
Target entry exists for the active source identity, but is obsolete.
Extra
Active target entry is not present in the active source identity set.