#[non_exhaustive]pub enum CompiledCatalogResolutionKind {
Requested,
Fallback,
SourceFallback,
Unresolved,
}Available on crate feature
catalog only.Expand description
How one compiled runtime message resolved for a requested-locale artifact.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Requested
The requested locale provided the final runtime message.
Fallback
A configured non-source fallback locale provided the final runtime message.
SourceFallback
The source locale provided the final runtime message through source fallback.
Unresolved
No locale provided a final runtime message.