#[non_exhaustive]pub struct CatalogCoverageOptions<'a> {
pub source_locale: &'a str,
pub locales: &'a [&'a str],
pub include_details: bool,
}Available on crate feature
catalog only.Expand description
Options controlling catalog coverage reports.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_locale: &'a strSource locale whose active message identities define expected coverage.
locales: &'a [&'a str]Optional target locale filter. Empty means all non-source locales present in catalogs.
include_details: boolWhether the report should include one detail row per classified message.
Implementations
Sourceimpl<'a> CatalogCoverageOptions<'a>
impl<'a> CatalogCoverageOptions<'a>