pub struct CatalogMessageKey {
pub msgid: String,
pub msgctxt: Option<String>,
}Available on crate feature
catalog only.Expand description
Stable lookup key for catalog messages.
Fields
msgid: StringSource message identifier.
msgctxt: Option<String>Optional gettext message context.
Implementations
Sourceimpl CatalogMessageKey
impl CatalogMessageKey
Sourcepub fn new(msgid: impl Into<String>, msgctxt: Option<String>) -> Self
pub fn new(msgid: impl Into<String>, msgctxt: Option<String>) -> Self
Creates a message key from msgid and optional context.
Sourcepub fn with_context(
msgid: impl Into<String>,
msgctxt: impl Into<String>,
) -> Self
pub fn with_context( msgid: impl Into<String>, msgctxt: impl Into<String>, ) -> Self
Creates a message key from msgid and context.
This is equivalent to CatalogMessageKey::new(msgid, Some(msgctxt.into()))
but lets callers pass borrowed context strings without spelling the
intermediate Some(String).